package com.datacloudsec.scan.service.impl;

import com.datacloudsec.exception.UEException;
import com.datacloudsec.scan.common.Constant;
import com.datacloudsec.scan.dao.RoleMapper;
import com.datacloudsec.scan.dao.UserMapper;
import com.datacloudsec.scan.entity.Perm;
import com.datacloudsec.scan.entity.User;
import com.datacloudsec.scan.service.IConfig;
import com.datacloudsec.scan.service.IUser;
import com.datacloudsec.utils.DateUtil;
import com.datacloudsec.utils.EntryResult;
import com.datacloudsec.utils.IPUtil;
import com.datacloudsec.utils.InstanceUtil;
import com.datacloudsec.utils.ObjectUtil;
import com.datacloudsec.utils.SecretUtil;
import java.io.File;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Date;
import java.util.Enumeration;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpSession;
import org.apache.commons.io.FileUtils;
import org.apache.commons.lang.StringUtils;
import org.apache.log4j.Logger;

/* loaded from: com_datacloudsec_scan_service_impl.jar:com/datacloudsec/scan/service/impl/UserService.class */
public class UserService implements IUser {
    private UserMapper userMapper = (UserMapper) InstanceUtil.newDaoInstance(UserMapper.class);
    private RoleMapper roleMapper = (RoleMapper) InstanceUtil.newDaoInstance(RoleMapper.class);
    private IConfig config = (IConfig) InstanceUtil.newServiceInstance(ConfigService.class);
    private static final Logger LOG = Logger.getLogger(UserService.class);
    private static Map<String, Object> loginErrCount = new HashMap();

    public void delete(Integer id, Integer version) throws Exception {
        if (id.intValue() == 1) {
            throw new UEException("admin账户不允许删除！");
        }
        Integer rcount = Integer.valueOf(this.userMapper.delete(id, version));
        if (rcount.intValue() == 0) {
            throw new UEException("数据已被修改或删除，请刷新页面或返回");
        }
        try {
            File userdir = new File(Constant.WORK_DIR, "user/" + id);
            FileUtils.deleteDirectory(userdir);
        } catch (IOException e) {
            LOG.error("删除用户配置目录出错", e);
        }
    }

    public void login(HttpServletRequest req, String name, String password, String code) throws Exception {
        loginInfo(req, validUser(req, name, password, code));
    }

    public void loginInfo(HttpServletRequest req, User user) throws Exception {
        HttpSession session = req.getSession();
        String ip = IPUtil.getIpAddress(req);
        Date loginTime = new Date();
        String updDate = user.getVal3();
        User u = new User();
        u.setId(user.getId());
        u.setLoginTime(loginTime);
        u.setIp(ip);
        if (StringUtils.isBlank(updDate)) {
            u.setVal3(new StringBuilder(String.valueOf(System.currentTimeMillis())).toString());
        }
        this.userMapper.updateOther(u);
        user.setLoginTime(loginTime);
        user.setIp(ip);
        List<Perm> perms = this.userMapper.getPermissionByUser(user.getRid());
        List<String> actions = new ArrayList<>();
        for (Perm p : perms) {
            actions.add(p.getAction());
        }
        session.setAttribute("userInfo", user);
        session.setAttribute("userPerms", perms);
        session.setAttribute("userAction", actions);
        session.setAttribute("userRole", this.userMapper.getUserRoleById(user.getRid()));
        session.setAttribute("userRule", EntryResult.parseEntry(this.userMapper.getUserRuleById(user.getRid()), "tname", "cond"));
        session.setAttribute("childMenus", EntryResult.parseEntryListMap(this.roleMapper.getMenusForCustom(), "parentId"));
        session.setAttribute("customMenus", this.roleMapper.getFirstMenus());
    }

    public void logout(HttpSession session) throws Exception {
        User user = (User) session.getAttribute("userInfo");
        Enumeration<String> em = session.getAttributeNames();
        while (em.hasMoreElements()) {
            session.removeAttribute(em.nextElement().toString());
        }
        if (user != null) {
            session.setAttribute("username", user.getName());
        }
    }

    public User validUser(HttpServletRequest req, String name, String password, String code) throws Exception {
        HttpSession session = req.getSession();
        if (code != null) {
            String sessionCode = (String) session.getAttribute("code");
            session.removeAttribute("code");
            if (StringUtils.isBlank(code) || !code.equalsIgnoreCase(sessionCode)) {
                LOG.error("code=" + code + ",sessionCode=" + sessionCode);
                throw new UEException("验证码错误");
            }
        }
        User user = this.userMapper.getUserByName(name);
        if (user == null) {
            throw new UEException("用户名或密码错误");
        }
        Long lockTime = user.getLockTime();
        if (lockTime.longValue() != 0) {
            if (lockTime.longValue() == -1) {
                throw new UEException("该用户已被锁定，请联系管理员解锁");
            }
            long time = (ObjectUtil.getLong(this.config.getValueByName("userLockTime"), 300L).longValue() * 1000) - (System.currentTimeMillis() - lockTime.longValue());
            if (time > 0) {
                throw new UEException("该用户已被锁定，离解锁时间还有：" + DateUtil.time2Str(Long.valueOf(time)));
            }
        }
        if (!password.equalsIgnoreCase(user.getPassword())) {
            int n = addError(user);
            if (n <= 0) {
                throw new UEException("该用户已被锁定，离解锁时间还有：" + DateUtil.time2Str(Long.valueOf(ObjectUtil.getLong(this.config.getValueByName("userLockTime"), 300L).longValue() * 1000)));
            }
            throw new UEException("用户名或密码错误，如果再错误" + n + "次，用户将被锁定。");
        }
        loginErrCount.remove("login_error_" + user.getId());
        return user;
    }

    private int addError(User user) throws Exception {
        String key = "login_error_" + user.getId();
        int num = ObjectUtil.getInt(loginErrCount.get(key), 0) + 1;
        Long currTime = Long.valueOf(System.currentTimeMillis());
        int maxPwdError = ObjectUtil.getInt(this.config.getValueByName("maxPwdError"), 5);
        if (num >= maxPwdError) {
            User u = new User();
            u.setId(user.getId());
            u.setLockTime(currTime);
            user.setLockTime(currTime);
            this.userMapper.updateOther(u);
            loginErrCount.remove(key);
            return 0;
        }
        loginErrCount.put(key, Integer.valueOf(num));
        return maxPwdError - num;
    }

    public int queryCount(String name, String realName, Integer roleId, String ip, String dateFrom, String dateTo) throws Exception {
        return this.userMapper.searchCount(name, realName, roleId, ip, dateFrom, dateTo);
    }

    public List<Map<String, Object>> query(String name, String realName, Integer roleId, String ip, String dateFrom, String dateTo, Integer offset, Integer limit) throws Exception {
        return this.userMapper.search(name, realName, roleId, ip, dateFrom, dateTo, offset, limit);
    }

    public void updateUser(HttpSession session, Integer id, String name, String realName, Integer roleId, String hide_name, Integer regionSid, Integer version, Integer regionCid, String email, String ips, String urls) throws Exception {
        if (StringUtils.isNotBlank(hide_name) && !name.equals(hide_name)) {
            Integer count = getUserCountByName(name);
            if (count.intValue() > 0) {
                throw new UEException("用户名已存在！");
            }
        }
        User u = new User();
        u.setId(id);
        u.setName(name);
        u.setRealName(realName);
        u.setVal1(email);
        u.setRegionSid(regionSid);
        u.setRegionCid(regionCid);
        u.setRid(roleId);
        u.setVersion(version);
        u.setIps(ips);
        u.setUrls(IPUtil.urlFormat(urls));
        Integer rcount = Integer.valueOf(this.userMapper.update(u));
        if (rcount.intValue() == 0) {
            throw new UEException("数据已被修改或删除，请刷新页面或返回");
        }
        User sUser = (User) session.getAttribute("userInfo");
        if (sUser != null && u != null) {
            try {
                if (u.getId().intValue() == sUser.getId().intValue()) {
                    u.setVersion(Integer.valueOf(version.intValue() + 1));
                    session.setAttribute("userInfo", u);
                }
            } catch (Exception e) {
                LOG.error("", e);
            }
        }
    }

    public String updatePWD(Integer id, String password, String before_pwd) throws Exception {
        String pwd = this.userMapper.getPassWordById(id);
        String val3 = new StringBuilder(String.valueOf(System.currentTimeMillis())).toString();
        if (!pwd.equals(before_pwd)) {
            throw new UEException("原始密码错误！");
        }
        User u = new User();
        u.setId(id);
        u.setPassword(password);
        u.setVal3(val3);
        this.userMapper.updateOther(u);
        return val3;
    }

    public Integer getUserCountByName(String name) throws Exception {
        return this.userMapper.getCountByName(name);
    }

    public User insertUser(String name, String password, String realName, Integer roleId, Integer regionSid, Integer regionCid, String email, String ips, String urls) throws Exception {
        Integer count = getUserCountByName(name);
        if (count.intValue() > 0) {
            throw new UEException("用户名已存在！");
        }
        User u = new User();
        u.setName(name);
        u.setRealName(realName);
        u.setVal1(email);
        u.setPassword(password);
        u.setRegionSid(regionSid);
        u.setRegionCid(regionCid);
        u.setRid(roleId);
        u.setIps(ips);
        u.setUrls(IPUtil.urlFormat(urls));
        this.userMapper.insert(u);
        return u;
    }

    public User getUserById(Integer id) throws Exception {
        return this.userMapper.getUserById(id);
    }

    public void lock(Integer id, Long lockTime) throws Exception {
        this.userMapper.lock(id, lockTime);
    }

    public void resetPWD(Integer id) throws Exception {
        User u = new User();
        u.setId(id);
        u.setPassword(SecretUtil.digestSha1("123456", "sha-1"));
        this.userMapper.updateOther(u);
    }

    public void validCode(String validCode, String name) throws Exception {
        this.userMapper.validCode(validCode, name);
    }

    public User getUserByName(String name) throws Exception {
        return this.userMapper.getUserByName(name);
    }

    public void updPwdByName(String name, String password, String newKey) throws Exception {
        this.userMapper.updPwdByName(name, password, newKey);
    }
}
